@@ -5,6 +5,10 @@ import warnings
 
 from astropy.io import fits
 from astropy.table import Table
+
+# Module-level constants for Sacc file format versions
+SACCFVER = 2  # Current FITS version
+SACCHDF5VER = 1  # Current HDF5 version
 import numpy as np
 
 from .tracers import BaseTracer
@@ -940,10 +944,10 @@ class Sacc:
 
         # Create the actual fits object
         primary_header = fits.Header()
+        primary_header['SACCFVER'] = SACCFVER
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", category=fits.verify.VerifyWarning)
-            hdus = [fits.PrimaryHDU(header=primary_header)] + \
-                    [fits.table_to_hdu(table) for table in tables]
+            hdus = [fits.PrimaryHDU(header=primary_header)] + [fits.table_to_hdu(table) for table in tables]
         hdu_list = fits.HDUList(hdus)
         io.astropy_buffered_fits_write(filename, hdu_list)
 
@@ -962,36 +966,34 @@ class Sacc:
         """
         cov = None
         metadata = None
+        fitsver = None
 
         with fits.open(filename, mode="readonly") as f:
             tables = []
-            for hdu in f:
+            for idx, hdu in enumerate(f):
                 if hdu.name.lower() == 'primary':
-                    # The primary table is not a data table,
-                    # but in older files it was used to store metadata
                     header = hdu.header
+                    fitsver = header.get('SACCFVER', None)
+                    if fitsver is None:
+                        fitsver = 1
+                    if fitsver > SACCFVER:
+                        raise RuntimeError(f"Unsupported SACC FITS version: {fitsver}")
                     if "NMETA" in header:
                         metadata = {}
-                        # Older format metadata is kept in the primary
-                        # header, with keys KEY0, VAL0, etc.
                         n_meta = header['NMETA']
                         for i in range(n_meta):
                             k = header[f'KEY{i}']
                             v = header[f'VAL{i}']
                             metadata[k] = v
                 elif hdu.name.lower() == 'covariance':
-                    # Legacy covariance - HDU will just be called covariance
-                    # instead of the full name given by BaseIO.
-                    # Note that this will also allow us to use multiple
-                    # covariances in future.
                     cov = BaseCovariance.from_hdu(hdu)
                 else:
                     tables.append(Table.read(hdu))
 
-        # add the metadata table, if we are in the legacy format
         if metadata is not None:
             tables.append(io.metadata_to_table(metadata))
 
+        # Pass version to from_tables if needed (future-proofing)
         return cls.from_tables(tables, cov=cov)
 
     def save_hdf5(self, filename, overwrite=False, compression='gzip', compression_opts=4):
@@ -1027,6 +1029,8 @@ class Sacc:
                 table.meta['EXTNAME'] = extname
 
         with h5py.File(filename, 'w') as f:
+            # Write version dataset
+            f.create_dataset('sacc_hdf5_version', data=np.array([SACCHDF5VER], dtype='i4'))
             used_names = {}
             for table in tables:
                 # Build a meaningful dataset name
@@ -1087,9 +1091,19 @@ class Sacc:
         """
         import h5py
         recovered_tables = []
+        hdf5ver = None
         with h5py.File(filename, 'r') as f:
+            # Check version
+            if 'sacc_hdf5_version' in f:
+                hdf5ver = int(np.array(f['sacc_hdf5_version'])[0])
+            else:
+                hdf5ver = 1
+            if hdf5ver > SACCHDF5VER:
+                raise RuntimeError(f"Unsupported SACC HDF5 version: {hdf5ver}")
             # Read all datasets (not groups) in the order they appear
             for key in f.keys():
+                if key == 'sacc_hdf5_version':
+                    continue
                 item = f[key]
                 if isinstance(item, h5py.Dataset):
                     table = Table.read(f, path=key)
