@@ -151,8 +151,7 @@ def invert_spd_matrix(M, strict=True):
         invM, info = scipy.linalg.lapack.dpotri(L)
         if info:
             raise ValueError("Matrix is not symmetric-positive-definite")
-        else:
-            invM = np.triu(invM) + np.triu(invM, k=1).T
+        invM = np.triu(invM) + np.triu(invM, k=1).T
     # Otherwise we use the generic (and also slower) method that will
     # work if, due to numerical issues, the matrix is not quite SPD
     else:
@@ -166,3 +165,48 @@ def camel_case_split_and_lowercase(identifier):
                           '|(?<=[A-Z])(?=[A-Z][a-z])|$)',
                           identifier)
     return [m.group(0).lower() for m in matches]
+
+
+def convert_to_astropy_table(obj):
+    try:
+        from tables_io.convUtils import convertToApTables
+        version = 1
+    except ImportError:
+        try:
+            from tables_io import convert_table
+            version = 2
+        except ImportError:
+            raise ImportError("Error importing table conversion tool from tables_io. "
+                              "Maybe they changed its name again. Please open an issue, "
+                              "assuming you have tables_io installed.")
+
+    if version == 1:
+        return convertToApTables(obj)
+    if version == 2:
+        return convert_table(obj, "astropyTable")
+    raise ValueError("Unknown version of tables_io conversion tool.")
+
+
+def numpy_to_vanilla(x):
+    """
+    Convert a NumPy scalar type to its corresponding Python built-in type.
+
+    Parameters
+    ----------
+    x : numpy scalar
+        A NumPy scalar value (e.g., np.str_, np.int64, np.float64, np.bool).
+
+    Returns
+    -------
+    object
+        The equivalent Python built-in type (e.g., str, int, float, bool).
+    """
+    if type(x) == np.str_:
+        x = str(x)
+    elif type(x) == np.int64:
+        x = int(x)
+    elif type(x) == np.float64:
+        x = float(x)
+    elif type(x) == np.bool:
+        x = bool(x)
+    return x
